<?php
class Configurator {
	/**
	* Defines the root directory of the Drupal installation.
	*
	* @var string
	*/
	protected $drupalRoot = '';
	/**
	* Execute the non-interactive installer.
	*
	* @see install_drupal()
	*/
	public function doConfigure($rootDir, $settings) {
		$this->drupalRoot = $rootDir;

		$autoloader = require $this->drupalRoot . '/autoload.php';

		$this->rewriteConfig($settings);
		$this->setSettings($settings, $autoloader);
	}

	protected function setSettings($settings, $autoloader) {
		$cwd = getcwd();
		chdir($this->drupalRoot);
		$request = Symfony\Component\HttpFoundation\Request::createFromGlobals();
		$kernel = Drupal\Core\DrupalKernel::createFromRequest($request, $autoloader, 'prod', FALSE);
		$kernel->boot();
		$kernel->loadLegacyIncludes();
	
		$siteSettings = \Drupal::configFactory()->getEditable('system.site');
		$siteSettings->set('name', $settings['site']['name']);
		$siteSettings->set('mail', $settings['site']['mail']);
		$siteSettings->save(true);
	
		$account = Drupal\user\Entity\User::load(1);
		$account->name = $settings['admin']['name'];
		$account->mail = $settings['admin']['mail'];
		$account->init = $settings['admin']['mail'];
		$account->pass = $settings['admin']['password'];
		$account->save();
		chdir($cwd);
	}
	
	protected function rewriteConfig($settings) {
		include_once $this->drupalRoot . '/core/includes/install.inc';
		include_once $this->drupalRoot . '/core/includes/bootstrap.inc';
		$config = $this->drupalRoot . '/sites/default/settings.php';
		chmod($config, 0777);
	
		$params['databases']['default']['default']['username'] = (object) array('value' => $settings['database']['username'], 'required' => true);
		$params['databases']['default']['default']['password'] = (object) array('value' => $settings['database']['password'], 'required' => true);
		drupal_rewrite_settings($params, $config);
		chmod($config, 0444);
	}
}